@@ -27,7 +27,7 @@ _datastore = LocalProxy(lambda: _security.datastore)
 
 def generate_confirmation_link(user):
     token = generate_confirmation_token(user)
-    return url_for_security('confirm_email', token=token, _extenal=True), token
+    return url_for_security('confirm_email', token=token, _external=True), token
 
 
 def send_confirmation_instructions(user):
